@@ -1,13 +1,15 @@
 import pickle
 from functools import partial
 
-import numpy as np
 import pytest
-from numpy.testing import assert_equal, assert_, assert_array_equal
-from numpy.random import (Generator, MT19937, PCG64, Philox, SFC64)
+
+import numpy as np
+from numpy.random import MT19937, PCG64, PCG64DXSM, SFC64, Generator, Philox
+from numpy.testing import assert_, assert_array_equal, assert_equal
+
 
 @pytest.fixture(scope='module',
-                params=(np.bool_, np.int8, np.int16, np.int32, np.int64,
+                params=(np.bool, np.int8, np.int16, np.int32, np.int64,
                         np.uint8, np.uint16, np.uint32, np.uint64))
 def dtype(request):
     return request.param
@@ -66,13 +68,12 @@ def comp_state(state1, state2):
             identical &= comp_state(state1[key], state2[key])
     elif type(state1) != type(state2):
         identical &= type(state1) == type(state2)
+    elif (isinstance(state1, (list, tuple, np.ndarray)) and isinstance(
+            state2, (list, tuple, np.ndarray))):
+        for s1, s2 in zip(state1, state2):
+            identical &= comp_state(s1, s2)
     else:
-        if (isinstance(state1, (list, tuple, np.ndarray)) and isinstance(
-                state2, (list, tuple, np.ndarray))):
-            for s1, s2 in zip(state1, state2):
-                identical &= comp_state(s1, s2)
-        else:
-            identical &= state1 == state2
+        identical &= state1 == state2
     return identical
 
 
@@ -434,13 +435,13 @@ class RNG:
     def test_pickle(self):
         pick = pickle.dumps(self.rg)
         unpick = pickle.loads(pick)
-        assert_((type(self.rg) == type(unpick)))
+        assert_(type(self.rg) == type(unpick))
         assert_(comp_state(self.rg.bit_generator.state,
                            unpick.bit_generator.state))
 
         pick = pickle.dumps(self.rg)
         unpick = pickle.loads(pick)
-        assert_((type(self.rg) == type(unpick)))
+        assert_(type(self.rg) == type(unpick))
         assert_(comp_state(self.rg.bit_generator.state,
                            unpick.bit_generator.state))
 
@@ -478,7 +479,7 @@ class RNG:
                            self.seed_vector_bits - 1) + 1
         bg = self.bit_generator(seed)
         state1 = bg.state
-        bg  = self.bit_generator(seed[0])
+        bg = self.bit_generator(seed[0])
         state2 = bg.state
         assert_(not comp_state(state1, state2))
 
@@ -653,7 +654,7 @@ class RNG:
             rg.standard_gamma(1.0, out=existing[::3])
 
     def test_integers_broadcast(self, dtype):
-        if dtype == np.bool_:
+        if dtype == np.bool:
             upper = 2
             lower = 0
         else:
@@ -699,7 +700,7 @@ class RNG:
         assert out.shape == (1,)
 
     def test_integers_broadcast_errors(self, dtype):
-        if dtype == np.bool_:
+        if dtype == np.bool:
             upper = 2
             lower = 0
         else:
@@ -735,7 +736,7 @@ class TestMT19937(RNG):
         self.rg.bit_generator.state = state
         state2 = self.rg.bit_generator.state
         assert_((state[1] == state2['state']['key']).all())
-        assert_((state[2] == state2['state']['pos']))
+        assert_(state[2] == state2['state']['pos'])
 
 
 class TestPhilox(RNG):
@@ -774,6 +775,18 @@ class TestPCG64(RNG):
         cls._extra_setup()
 
 
+class TestPCG64DXSM(RNG):
+    @classmethod
+    def setup_class(cls):
+        cls.bit_generator = PCG64DXSM
+        cls.advance = 2**63 + 2**31 + 2**15 + 1
+        cls.seed = [12345]
+        cls.rg = Generator(cls.bit_generator(*cls.seed))
+        cls.initial_state = cls.rg.bit_generator.state
+        cls.seed_vector_bits = 64
+        cls._extra_setup()
+
+
 class TestDefaultRNG(RNG):
     @classmethod
     def setup_class(cls):
